summaryrefslogtreecommitdiffstats
path: root/korganizer/calendarview.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/calendarview.h')
-rw-r--r--korganizer/calendarview.h39
1 files changed, 20 insertions, 19 deletions
diff --git a/korganizer/calendarview.h b/korganizer/calendarview.h
index 6cdc3154..cd04ee98 100644
--- a/korganizer/calendarview.h
+++ b/korganizer/calendarview.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef CALENDARVIEW_H
#define CALENDARVIEW_H
@@ -56,16 +56,16 @@ class HTMLExportSettings;
using namespace KOrg;
using namespace KCal;
-class CalendarViewExtension : public QWidget
+class CalendarViewExtension : public TQWidget
{
public:
- CalendarViewExtension( TQWidget *parent, const char *name = 0 )
- : TQWidget( parent, name ) {}
+ CalendarViewExtension( TQWidget *tqparent, const char *name = 0 )
+ : TQWidget( tqparent, name ) {}
class Factory
{
public:
- virtual CalendarViewExtension *create( TQWidget *parent ) = 0;
+ virtual CalendarViewExtension *create( TQWidget *tqparent ) = 0;
};
};
@@ -81,14 +81,15 @@ class CalendarViewExtension : public QWidget
class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::Observer
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
Constructs a new calendar view widget.
- @param parent parent window
- @param name Qt internal widget object name
+ @param tqparent tqparent window
+ @param name TQt internal widget object name
*/
- CalendarView( TQWidget *parent = 0, const char *name = 0 );
+ CalendarView( TQWidget *tqparent = 0, const char *name = 0 );
virtual ~CalendarView();
class CalendarViewVisitor : public IncidenceBase::Visitor
@@ -115,7 +116,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
void setCalendar( Calendar * );
Calendar *calendar();
- QPair<ResourceCalendar *, TQString> viewSubResourceCalendar();
+ TQPair<ResourceCalendar *, TQString> viewSubResourceCalendar();
KOrg::History *history() const { return mHistory; }
@@ -288,7 +289,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
*/
void newEvent( ResourceCalendar *res, const TQString &subRes,
const TQString &summary,
- const TQString &description = TQString::null,
+ const TQString &description = TQString(),
const TQStringList &attachment = TQStringList(),
const TQStringList &attendees = TQStringList(),
const TQStringList &attachmentMimetypes = TQStringList(),
@@ -345,14 +346,14 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
/** create new todo, due on date */
void newTodo( ResourceCalendar *res, const TQString &subRes,
const TQDate &date );
/** create new todo with a parent todo */
void newSubTodo();
/** create new todo with a parent todo */
void newSubTodo( Todo * );
void newTodo( ResourceCalendar *res, const TQString &subRes,
const TQString &summary,
- const TQString &description = TQString::null,
+ const TQString &description = TQString(),
const TQStringList &attachments = TQStringList(),
const TQStringList &attendees = TQStringList(),
const TQStringList &attachmentMimetypes = TQStringList(),
@@ -371,7 +372,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
/**
- Check if clipboard tqcontains vCalendar event. The signal pasteEnabled() is
+ Check if clipboard contains vCalendar event. The signal pasteEnabled() is
emitted as result.
*/
void checkClipboard();
@@ -453,10 +454,10 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
*/
void appointment_delete();
- /* frees the selected to-do's children from it's relation, update the view */
+ /* frees the selected to-do's tqchildren from it's relation, update the view */
void todo_unsub();
- /* frees an incidence's children from it's relation, without update the view
+ /* frees an incidence's tqchildren from it's relation, without update the view
Works with any incidence type, although currently we only pass to-dos
*/
bool incidence_unsub( Incidence *inc );
@@ -464,7 +465,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
/** Make all sub-to-dos of the selected todo independent, update the view */
bool makeSubTodosIndependent ( );
- /** Make all children of incidence independent, not update the view
+ /** Make all tqchildren of incidence independent, not update the view
Works with any incidence type, although currently we only pass to-dos
*/
bool makeChildrenIndependent( Incidence *inc );
@@ -657,7 +658,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
// uncompleted subitems), notAllPurged is set to true.
bool purgeCompletedSubTodos( Todo* todo, bool &notAllPurged );
/** Returns all incidences having inc has their parent (or grand parent, etc.)
inc is included in the list too.
*/
void getIncidenceHierarchy( Incidence *inc, Incidence::List &incidences );
@@ -345,14 +346,14 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
void newTodo( ResourceCalendar *res, const TQString &subRes,
const TQDate &date );
- /** create new todo with a parent todo */
+ /** create new todo with a tqparent todo */
void newSubTodo();
@@ -345,14 +346,14 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
void newSubTodo();
- /** create new todo with a parent todo */
+ /** create new todo with a tqparent todo */
void newSubTodo( Todo * );
void newTodo( ResourceCalendar *res, const TQString &subRes,
@@ -657,7 +658,7 @@ class KDE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Calendar::
// uncompleted subitems), notAllPurged is set to true.
bool purgeCompletedSubTodos( Todo* todo, bool &notAllPurged );
- /** Returns all incidences having inc has their parent (or grand parent, etc.)
+ /** Returns all incidences having inc has their tqparent (or grand tqparent, etc.)
inc is included in the list too.
*/